{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for YAML.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/yaml.xml and 'make bootstrap'.
module Skylighting.Syntax.Yaml (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for YAML.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\byaml.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYaml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nafter-data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nafter-data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL{\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astringx\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rattribute-end\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rattribute-end\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4attribute-end-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4attribute-end-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX,]}\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rattribute-pre\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rattribute-pre\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL?\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL{\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEattribute-string\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1attribute-stringx\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1&\\S+(?=\\s+[\\[\\{])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\*\\S+(?=\\s+[\\[\\{])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS[\\|>][\\-\\+]?(?=(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEattribute-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEattribute-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-singleq\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rattribute-end\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBattribute-string-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBattribute-string-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-singleq\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4attribute-end-inline\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1attribute-stringx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1attribute-stringx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-doubleq\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rattribute-end\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANattribute-stringx-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANattribute-stringx-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-doubleq\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4attribute-end-inline\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBbefore-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBbefore-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS[\\|>][\\-\\+]?(?=(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4end-literal-operator\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL,(?:[&\\*]|!!)\\S*[\\|>][\\-\\+]?(?=(?:\\s*$|\\s+#))\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL{\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astringx\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL?\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmapping-key\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\-(?=\\s|$)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL{\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astringx\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSdefault-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSdefault-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL?\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL{\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBattribute-string-inline\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANattribute-stringx-inline\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1&\\S+(?=\\s+[\\[\\{])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\*\\S+(?=\\s+[\\[\\{])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdirective\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdirective\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKdpoints-attribute-pre\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKdpoints-attribute-pre\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL:\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rattribute-pre\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rattribute-pre\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!dpoints-hash-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL!dpoints-hash-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL:\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMhash-attribute-pre-inline\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMhash-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#dpoints-key-before-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL#dpoints-key-before-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL:\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCkey-before-literal-operator\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!dpoints-list-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL!dpoints-list-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL:\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMlist-attribute-pre-inline\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMlist-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4end-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4end-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-doubleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-doubleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULK\\\\(?:[\\s0abtnvfre\"/\\\\N_Lp]|x[a-fA-F0-9]{2}|u[a-fA-F0-9]{4}|U[a-fA-F0-9]{8})\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-singleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-singleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH''\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2find-literal-block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2find-literal-block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULf[ ]*\\t+\\s*(?=(?:(?:\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*|[^#])*[^#\\w\\|<>\"'])?[\\|>][\\-\\+]?(?:\\s*$|\\s+#))\SOH\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS[\\|>][\\-\\+]?(?=(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4literal-block-simple\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#([ ]+)[\\|>][\\-\\+]?(?=(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCliteral-block-only-operator\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULg([ ]*)\\:(?=\\s+(?:(?:\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*|[^#])*[^#\\w\\|<>\"'])?[\\|>][\\-\\+]?(?:\\s*$|\\s+#))\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1literal-block-key\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\183([ ]*)(?:[^\"'#\\-\\?\\s][^:#]*|\\-(?:[^\\s:#][^:#]*)?|\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*)(?=\\:\\s+(?:(?:\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*|[^#])*[^#\\w\\|<>\"'])?[\\|>][\\-\\+]?(?:\\s*$|\\s+#))\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1literal-block-key\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\179[ ]*(?:\\?[ ]*|\\-[ ]+){1,6}(?:(?:\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*|[^#\\-\\?\\s]|\\-[^\\s#])(?:(?:\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*|[^#])*[^#\\w\\|<>\"'])?)?[\\|>][\\-\\+]?(?:\\s*$|\\s+#)\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSstart-literal-block-withdash\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL4[ ]*(?:(?:[&\\*]|!!)\\S+\\s+)+[\\|>][\\-\\+]?(?:\\s*$|\\s+#)\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMstart-literal-block-other\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfind-values-list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfind-values-list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL5(?:null|Null|NULL|~)(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist-element\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULw(?:y|Y|yes|Yes|YES|n|N|no|No|NO|true|True|TRUE|false|False|FALSE|on|On|ON|off|Off|OFF)(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist-element\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\243(?:[\\-\\+]?(?:[0-9][0-9_]*\\.[0-9\\._]*|\\._*[0-9][0-9\\._]*)(?:[eE][\\-\\+]?[0-9]+)?|[\\-\\+]?[0-9][0-9_]*[eE][\\-\\+]?[0-9]+|[\\-\\+]?[0-9][0-9_]*(?:\\:[0-5]?[0-9])+\\.[0-9_]*|[\\-\\+]?\\.(?:inf|Inf|INF)\\b|\\.(?:nan|NaN|NAN)\\b)(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist-element\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\171(?:[\\-\\+]?[1-9][0-9_]*(?:\\:[0-5]?[0-9])+|[\\-\\+]?0(?:x_*[0-9a-fA-F][0-9a-fA-F_]*|o?_*[0-7][0-7_]*|b_*[01][01_]*)|(?:0|[\\-\\+]?[1-9][0-9_]*))(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist-element\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist-element\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist-element\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL?\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhash-element\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhash-element\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKhash-attribute-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKhash-attribute-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,}\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMhash-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMhash-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSdefault-attribute-pre-inline\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKhash-attribute-inline\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKhash-attribute-inline\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,}\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvalues-inline\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKhash-attribute-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhash-element\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhash-element\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\144[^\\s\"'#\\-,\\}\\s][^:#,\\}]*(?=\\:(?:\\s|$))|\\-(?:[^\\s:#,\\}][^:#,\\}]*)?(?=\\:(?:\\s|$))|\"(?:\\\\.|[^\"])+\"\\s*(?=\\:(?:\\s|$))|'(?:[^']|'')+'\\s*(?=\\:(?:\\s|$))\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL!dpoints-hash-attribute-pre-inline\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t:(?=\\s|$)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMhash-attribute-pre-inline\NUL}\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL,\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astringx\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\\s[\\|>][\\-\\+]?(?=(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBheader-literal-operator\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBheader-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBheader-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[\\|>][\\-\\+]?\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4literal-block-simple\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCkey-before-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCkey-before-literal-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBbefore-literal-operator\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL?\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL?\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfind-values-list\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfind-values-list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKlist-attribute-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKlist-attribute-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,]\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMlist-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMlist-attribute-pre-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSdefault-attribute-pre-inline\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKlist-attribute-inline\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKlist-attribute-inline\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,]\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvalues-inline\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKlist-attribute-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist-element\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist-element\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL]\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL[\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL{\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\142[^\"'#\\-,\\]\\s][^:#,\\]]*(?=\\:(?:\\s|$))|\\-(?:[^\\s:#,\\]][^:#,\\]]*)?(?=\\:(?:\\s|$))|\"(?:\\\\.|[^\"])+\"\\s*(?=\\:(?:\\s|$))|'(?:[^']|'')+'\\s*(?=\\:(?:\\s|$))\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL!dpoints-list-attribute-pre-inline\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t:(?=\\s|$)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMlist-attribute-pre-inline\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astringx\NUL,\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvalues-list\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANliteral-block-after-data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANliteral-block-after-data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ%1.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\s*\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBbefore-literal-operator\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKliteral-block-default\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKliteral-block-default\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\s*\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBbefore-literal-operator\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1literal-block-key\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1literal-block-key\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a%1\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\s*\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX:\\s\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCkey-before-literal-operator\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCkey-before-literal-operator\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-key-default\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-key-default\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\s*\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULW(?:[^\"'#\\-\\?\\s][^:#]*|\\-(?:[^\\s:#][^:#]*)?|\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*)(?=:\\s)\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL#dpoints-key-before-literal-operator\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f%1%2[ ]\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-key-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1%1%2%3[ ]{2}\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-key-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3%1%2%3%4[ ]{3}\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-key-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK%1%2%3%4%5[ ]{4}\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-key-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB%1%2%3%4%5%6[ ]{5}\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-key-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM%1%2%3%4%5%6%7[ ]{6}\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-key-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCliteral-block-only-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCliteral-block-only-operator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ%1.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\s*\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t(?:^|\\s)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4literal-block-simple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4literal-block-simple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\s.*$\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\s*\\S\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t(?:^|\\s)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a%1\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKliteral-block-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f%1%2[ ]\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKliteral-block-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1%1%2%3[ ]{2}\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKliteral-block-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3%1%2%3%4[ ]{3}\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKliteral-block-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK%1%2%3%4%5[ ]{4}\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKliteral-block-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB%1%2%3%4%5%6[ ]{5}\\s.*$\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKliteral-block-default\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmapping-key\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmapping-key\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\-(?=\\s|$)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdash\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nafter-data\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nafter-data\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nafter-data\NUL[\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL{\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astringx\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX---\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\.\\.\\.$\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEOD\NUL%\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdirective\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(?:^|\\s+)#\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2find-literal-block\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\-(?=\\s|$)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdash\NUL?\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmapping-key\NUL[\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL{\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nafter-data\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nafter-data\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nafter-data\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\130[^\"'#\\-\\s][^:#]*(?=\\:(?:\\s|$))|\\-(?:[^\\s:#][^:#]*)?(?=\\:(?:\\s|$))|\"(?:\\\\.|[^\"])+\"\\s*(?=\\:(?:\\s|$))|'(?:[^']|'')+'\\s*(?=\\:(?:\\s|$))\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKdpoints-attribute-pre\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t:(?=\\s|$)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rattribute-pre\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astringx\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4values-firstnonspace\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMstart-literal-block-other\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMstart-literal-block-other\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v([ ]+)!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANliteral-block-after-data\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n([ ]+)&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANliteral-block-after-data\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v([ ]+)\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANliteral-block-after-data\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a()!!\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s1\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK()&\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s1\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a()\\*\\S+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s1\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSstart-literal-block-withdash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSstart-literal-block-withdash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULi([ ]*)[\\?\\-]([ ]*)(?=(?:[^\"'#\\-\\?\\s][^:#]*|\\-(?:[^\\s:#][^:#]*)?|\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*):\\s)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULu([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)(?=(?:[^\"'#\\-\\?\\s][^:#]*|\\-(?:[^\\s:#][^:#]*)?|\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*):\\s)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s3\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\129([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)(?=(?:[^\"'#\\-\\?\\s][^:#]*|\\-(?:[^\\s:#][^:#]*)?|\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*):\\s)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s4\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\141([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)(?=(?:[^\"'#\\-\\?\\s][^:#]*|\\-(?:[^\\s:#][^:#]*)?|\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*):\\s)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s5\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\153([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)(?=(?:[^\"'#\\-\\?\\s][^:#]*|\\-(?:[^\\s:#][^:#]*)?|\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*):\\s)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s6\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\165([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)(?=(?:[^\"'#\\-\\?\\s][^:#]*|\\-(?:[^\\s:#][^:#]*)?|\"(?:\\\\.|[^\"])+\"\\s*|'(?:[^']|'')+'\\s*):\\s)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSliteral-block-key-withdash-s7\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&([ ]*)[\\?\\-]\\s*(?=[^#\\-\\?\\s]|\\-[^\\s#])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s1\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2([ ]*)[\\?\\-]([ ]*)[\\?\\-]\\s*(?=[^#\\-\\?\\s]|\\-[^\\s#])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL>([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]\\s*(?=[^#\\-\\?\\s]|\\-[^\\s#])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s3\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULJ([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]\\s*(?=[^#\\-\\?\\s]|\\-[^\\s#])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s4\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULV([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]\\s*(?=[^#\\-\\?\\s]|\\-[^\\s#])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s5\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULb([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]([ ]*)[\\?\\-]\\s*(?=[^#\\-\\?\\s]|\\-[^\\s#])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMliteral-block-withdash-s6\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-singleq\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astringx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astringx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4escaped-char-doubleq\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL%(?:null|Null|NULL|~)(?=(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULg(?:y|Y|yes|Yes|YES|n|N|no|No|NO|true|True|TRUE|false|False|FALSE|on|On|ON|off|Off|OFF)(?=(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\227(?:[\\-\\+]?(?:[0-9][0-9_]*\\.[0-9\\._]*|\\._*[0-9][0-9\\._]*)(?:[eE][\\-\\+]?[0-9]+)?|[\\-\\+]?[0-9][0-9_]*[eE][\\-\\+]?[0-9]+|[\\-\\+]?[0-9][0-9_]*(?:\\:[0-5]?[0-9])+\\.[0-9_]*|[\\-\\+]?\\.(?:inf|Inf|INF)\\b|\\.(?:nan|NaN|NAN)\\b)(?=(?:\\s*$|\\s+#))\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\155(?:[\\-\\+]?[1-9][0-9_]*(?:\\:[0-5]?[0-9])+|[\\-\\+]?0(?:x_*[0-9a-fA-F][0-9a-fA-F_]*|o?_*[0-7][0-7_]*|b_*[01][01_]*)|(?:0|[\\-\\+]?[1-9][0-9_]*))(?=(?:\\s*$|\\s+#))\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4values-firstnonspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4values-firstnonspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL%(?:null|Null|NULL|~)(?=(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULg(?:y|Y|yes|Yes|YES|n|N|no|No|NO|true|True|TRUE|false|False|FALSE|on|On|ON|off|Off|OFF)(?=(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\227(?:[\\-\\+]?(?:[0-9][0-9_]*\\.[0-9\\._]*|\\._*[0-9][0-9\\._]*)(?:[eE][\\-\\+]?[0-9]+)?|[\\-\\+]?[0-9][0-9_]*[eE][\\-\\+]?[0-9]+|[\\-\\+]?[0-9][0-9_]*(?:\\:[0-5]?[0-9])+\\.[0-9_]*|[\\-\\+]?\\.(?:inf|Inf|INF)\\b|\\.(?:nan|NaN|NAN)\\b)(?=(?:\\s*$|\\s+#))\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\155(?:[\\-\\+]?[1-9][0-9_]*(?:\\:[0-5]?[0-9])+|[\\-\\+]?0(?:x_*[0-9a-fA-F][0-9a-fA-F_]*|o?_*[0-7][0-7_]*|b_*[01][01_]*)|(?:0|[\\-\\+]?[1-9][0-9_]*))(?=(?:\\s*$|\\s+#))\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvalues-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvalues-inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL5(?:null|Null|NULL|~)(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULw(?:y|Y|yes|Yes|YES|n|N|no|No|NO|true|True|TRUE|false|False|FALSE|on|On|ON|off|Off|OFF)(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\243(?:[\\-\\+]?(?:[0-9][0-9_]*\\.[0-9\\._]*|\\._*[0-9][0-9\\._]*)(?:[eE][\\-\\+]?[0-9]+)?|[\\-\\+]?[0-9][0-9_]*[eE][\\-\\+]?[0-9]+|[\\-\\+]?[0-9][0-9_]*(?:\\:[0-5]?[0-9])+\\.[0-9_]*|[\\-\\+]?\\.(?:inf|Inf|INF)\\b|\\.(?:nan|NaN|NAN)\\b)(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\171(?:[\\-\\+]?[1-9][0-9_]*(?:\\:[0-5]?[0-9])+|[\\-\\+]?0(?:x_*[0-9a-fA-F][0-9a-fA-F_]*|o?_*[0-7][0-7_]*|b_*[01][01_]*)|(?:0|[\\-\\+]?[1-9][0-9_]*))(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvalues-list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvalues-list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL=(?:\\s|^)(?:null|Null|NULL|~)(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DEL(?:\\s|^)(?:y|Y|yes|Yes|YES|n|N|no|No|NO|true|True|TRUE|false|False|FALSE|on|On|ON|off|Off|OFF)(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\251(?:\\s|^)(?:[\\-\\+]?(?:[0-9][0-9_]*\\.[0-9\\._]*|\\._*[0-9][0-9\\._]*)(?:[eE][\\-\\+]?[0-9]+)?|[\\-\\+]?[0-9][0-9_]*[eE][\\-\\+]?[0-9]+|[\\-\\+]?[0-9][0-9_]*(?:\\:[0-5]?[0-9])+\\.[0-9_]*|[\\-\\+]?\\.(?:inf|Inf|INF)\\b|\\.(?:nan|NaN|NAN)\\b)(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\179(?:\\s|^)(?:[\\-\\+]?[1-9][0-9_]*(?:\\:[0-5]?[0-9])+|[\\-\\+]?0(?:x_*[0-9a-fA-F][0-9a-fA-F_]*|o?_*[0-7][0-7_]*|b_*[01][01_]*)|(?:0|[\\-\\+]?[1-9][0-9_]*))(?=\\s*[:,\\[\\]\\{\\}]|(?:\\s*$|\\s+#))\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULMDr Orlovsky MA (dr.orlovsky@gmail.com), Nibaldo Gonz\195\161lez (nibgonz@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.yaml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.yml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal"
